window.Gleam.initSearch([{"doc":"nbeet","title":"nbeet","content":"&lt;div align=&quot;center&quot;&gt;\r\n  &lt;a href=&quot;https://github.com/zwubs/nbeet&quot;&gt;\r\n    &lt;img src=&quot;https://raw.githubusercontent.com/zwubs/nbeet/main/images/nbeet.png&quot; alt=&quot;nbeet logo&quot; width=&quot;128&quot; height=&quot;128&quot;&gt;\r\n  &lt;/a&gt;\r\n\r\n  &lt;h1 align=&quot;center&quot; style=&quot;margin-bottom: 0; margin-top: 1rem;&quot;&gt;nbeet&lt;/h1&gt;\r\n\r\n  &lt;p align=&quot;center&quot;&gt;An NBT encoder and decoder for gleam&lt;/p&gt;\r\n\r\n[![Package Version](https://img.shields.io/hexpm/v/nbeet)](https://hex.pm/packages/nbeet)\r\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/nbeet/)\r\n\r\n&lt;/div&gt;\r\n\r\n## About\r\n`nbeet` is a gleam package for all your NBT needs. For those that don&#39;t know NBT (Named Binary Tag) is a file format utilized by the game Minecraft for storing information. This package focuses on encoding and decoding NBT data and has syntax inspired by [`gleam_json`](https://github.com/gleam-lang/json) and [`bison`](https://github.com/massivefermion/bison) packages.\r\n\r\n## Installation\r\nAdd `nbeet` to your Gleam project.\r\n\r\n```sh\r\ngleam add nbeet\r\n```\r\n\r\n## Usage\r\n### Encoding\r\n```gleam\r\nimport nbeet.{byte, compound, nbt, string}\r\n\r\npub fn encode_truth() -&gt; Result(BitArray, Nil) {\r\n  let nbt = \r\n    nbt(\r\n      &quot;in beet we&quot;,\r\n      compound([#(&quot;trust&quot;, byte(1)), #(&quot;must&quot;, string(&quot;true&quot;)), ])\r\n    )\r\n  nbeet.encode(nbt)\r\n}\r\n```\r\n\r\n### Decoding\r\n```gleam\r\nimport gleam/dynamic\r\nimport gleam/result\r\nimport nbeet\r\n\r\npub type InBeetWe {\r\n  InBeetWe(trust: Int, must: String)\r\n}\r\n\r\nfn decode_truth(nbt: BitArray) -&gt; Result(InBeetWe, Nil) {\r\n  let decoder =\r\n    dynamic.decode2(\r\n      InBeetWe,\r\n      dynamic.field(&quot;trust&quot;, dynamic.int),\r\n      dynamic.field(&quot;must&quot;, dynamic.string),\r\n    )\r\n  use #(name, in_beet_we) &lt;- result.try(nbeet.decode(nbt, decoder))\r\n  Ok(in_beet_we)\r\n}\r\n```\r\n","url":"index.html"},{"doc":"nbeet","title":"byte","content":"pub fn byte(byte: Int) -&gt; Tag\n\nSynonyms:\nnbeet.byte\nnbeet byte","url":"nbeet.html#byte"},{"doc":"nbeet","title":"byte_array","content":"pub fn byte_array(byte_array: BitArray) -&gt; Tag\n\nSynonyms:\nnbeet.byte_array\nnbeet byte_array","url":"nbeet.html#byte_array"},{"doc":"nbeet","title":"compound","content":"pub fn compound(compound: List(#(String, Tag))) -&gt; Tag\n\nSynonyms:\nnbeet.compound\nnbeet compound","url":"nbeet.html#compound"},{"doc":"nbeet","title":"decode","content":"pub fn decode(\n  bit_array: BitArray,\n  decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(#(String, a), List(DecodeError))\n\nSynonyms:\nnbeet.decode\nnbeet decode","url":"nbeet.html#decode"},{"doc":"nbeet","title":"double","content":"pub fn double(double: Float) -&gt; Tag\n\nSynonyms:\nnbeet.double\nnbeet double","url":"nbeet.html#double"},{"doc":"nbeet","title":"encode","content":"pub fn encode(nbt: Nbt) -&gt; Result(BitArray, Nil)\n\nSynonyms:\nnbeet.encode\nnbeet encode","url":"nbeet.html#encode"},{"doc":"nbeet","title":"float","content":"pub fn float(float: Float) -&gt; Tag\n\nSynonyms:\nnbeet.float\nnbeet float","url":"nbeet.html#float"},{"doc":"nbeet","title":"int","content":"pub fn int(int: Int) -&gt; Tag\n\nSynonyms:\nnbeet.int\nnbeet int","url":"nbeet.html#int"},{"doc":"nbeet","title":"int_array","content":"pub fn int_array(int_array: List(Int)) -&gt; Tag\n\nSynonyms:\nnbeet.int_array\nnbeet int_array","url":"nbeet.html#int_array"},{"doc":"nbeet","title":"list","content":"pub fn list(tag: fn(a) -&gt; Tag, list: List(a)) -&gt; Tag\n\nSynonyms:\nnbeet.list\nnbeet list","url":"nbeet.html#list"},{"doc":"nbeet","title":"long","content":"pub fn long(long: Int) -&gt; Tag\n\nSynonyms:\nnbeet.long\nnbeet long","url":"nbeet.html#long"},{"doc":"nbeet","title":"long_array","content":"pub fn long_array(long_array: List(Int)) -&gt; Tag\n\nSynonyms:\nnbeet.long_array\nnbeet long_array","url":"nbeet.html#long_array"},{"doc":"nbeet","title":"nbt","content":"pub fn nbt(name: String, tag: Tag) -&gt; Nbt\n\nSynonyms:\nnbeet.nbt\nnbeet nbt","url":"nbeet.html#nbt"},{"doc":"nbeet","title":"short","content":"pub fn short(short: Int) -&gt; Tag\n\nSynonyms:\nnbeet.short\nnbeet short","url":"nbeet.html#short"},{"doc":"nbeet","title":"string","content":"pub fn string(string: String) -&gt; Tag\n\nSynonyms:\nnbeet.string\nnbeet string","url":"nbeet.html#string"},{"doc":"nbeet","title":"nbeet","content":"","url":"nbeet.html"},{"doc":"nbeet/gzip","title":"compress","content":"pub fn compress(data: BitArray) -&gt; BitArray\n\nSynonyms:\nnbeet/gzip.compress\nnbeet/gzip compress","url":"nbeet/gzip.html#compress"},{"doc":"nbeet/gzip","title":"decompress","content":"pub fn decompress(data: BitArray) -&gt; BitArray\n\nSynonyms:\nnbeet/gzip.decompress\nnbeet/gzip decompress","url":"nbeet/gzip.html#decompress"},{"doc":"nbeet/gzip","title":"nbeet/gzip","content":"","url":"nbeet/gzip.html"}]);